@@ -6,7 +6,7 @@ __metaclass__ = Database.DefaultMeta
 class User:
     name = Column(String(30))
 
-@Database.foreign_key(User, one_to_one = True)
+@Database.one_to_one(User)
 class Contact:
     email = Column(String(70))
     address = Column(String(70))
@@ -20,8 +20,8 @@ if __name__ == '__main__':
     contact = Contact(email = 'quick.orm.feedback@gmail.com', address = 'Shenzhen, China')
     user = User(name = 'Tyler Long', contact = contact)
     db.session.add_then_commit(user)
-    
+
     user = db.session.query(User).get(1)
     print 'User:', user.name
     print 'Email:', user.contact.email
-    print 'Address:', user.contact.address
+    print 'Address:', user.contact.address
\ No newline at end of file
